@@ -40,7 +40,12 @@ def _get_requests(client, parameters):
         query &= R().asset.product.id.oneof(parameters['product']['choices'])
     if parameters.get('rr_type') and parameters['rr_type']['all'] is False:
         query &= R().type.oneof(parameters['rr_type']['choices'])
-    return client.requests.filter(query).select('-asset.params', '-asset.configuration')
+    return client.requests.filter(query).select(
+        '-asset.params',
+        '-asset.configuration',
+        '-activation_key',
+        '-template',
+    )
 
 
 def _get_request_count_group_by_type(client, parameters):
@@ -434,7 +439,7 @@ def _process_product_data(report_data, request):
 def _process_country_data(report_data, request):
     country = get_dict_element(request, 'asset', 'tiers', 'customer', 'contact_info', 'country')
     if country:
-        country_name = COUNTRIES[country.upper()]
+        country_name = COUNTRIES.get(country.upper(), "Antarctica")
 
         country_data = report_data['country'].get(
             country_name,
