@@ -7,18 +7,18 @@ from openpyxl.worksheet.datavalidation import DataValidation
 
 from connect.cli.core.utils import validate_output_options
 from connect.cli.plugins.shared.export import (
-    _alter_attributes_sheet,
-    _get_translation_workbook,
+    alter_attributes_sheet,
+    get_translation_workbook,
 )
 
 
 def dump_translation(
-    api_url, api_key, translation_id, output_file, verbose=False, output_path=None,
+    client, translation_id, output_file, output_path=None,
 ):
     output_file = validate_output_options(output_path, output_file, default_dir_name=translation_id)
-    wb = _get_translation_workbook(api_url, api_key, translation_id, verbose)
+    wb = get_translation_workbook(client, translation_id)
     _alter_general_sheet(wb['General'])
-    _alter_attributes_sheet(wb['Attributes'])
+    alter_attributes_sheet(wb['Attributes'])
     wb.save(output_file)
     return output_file
 
